==> geopsypack-src-3.4.1.tar.gz: geopsypack-src-3.4.1/QGpGuiMath/src/QGpGuiMath.h <==
#ifndef QGPGUIMATH_HEADERS
#define QGPGUIMATH_HEADERS

// All headers of QGpGuiMath library

#include "ComplexStatisticalPlotProxy.h"
#include "CoordinateConvert.h"
#include "CoordinateFileWidget.h"
#include "CurveBrowser.h"
#include "CurveBrowserCut.h"
#include "CurveBrowserDelegate.h"
#include "CurveBrowserItem.h"
#include "CurveBrowserResample.h"
#include "CurveBrowserSmooth.h"
#include "CurveBrowserSplit.h"
#include "CurveBrowserValidate.h"
#include "CurvePlotProxy.h"
#include "CurveProperties.h"
#include "CurveSelector.h"
#include "CurveSelectorItem.h"
#include "GeographicalReference.h"
#include "GuiMathGlobal.h"
#include "ImageLayer.h"
#include "ImageScalingPoint.h"
#include "QGpGuiMathDLLExport.h"
#include "RealStatisticalPlotProxy.h"
#include "SamplingParameterWidget.h"
#include "SmoothingParameterWidget.h"
#include "WindowFunctionParameterWidget.h"
#include "ui_CoordinateConvert.h"
#include "ui_CoordinateFileWidget.h"
#include "ui_CurveBrowser.h"
#include "ui_CurveBrowserCut.h"
#include "ui_CurveBrowserResample.h"
#include "ui_CurveBrowserSmooth.h"
#include "ui_CurveBrowserSplit.h"
#include "ui_CurveBrowserValidate.h"
#include "ui_CurveProperties.h"
#include "ui_CurveSelector.h"
#include "ui_GeographicalReference.h"
#include "ui_ImageLayerProperties.h"
#include "ui_ImageScalingPoint.h"
#include "ui_SamplingParameterWidget.h"
#include "ui_SmoothingParameterWidget.h"
#include "ui_WindowFunctionParameterWidget.h"

#ifndef GP_EXPLICIT_LIBRARY_NAMESPACE
using namespace QGpGuiMath;
#endif

#endif // QGPGUIMATH_HEADERS

==> geopsypack-src-3.5.1.tar.gz: geopsypack-src-3.5.1/QGpGuiMath/src/QGpGuiMath.h <==
#ifndef QGPGUIMATH_HEADERS
#define QGPGUIMATH_HEADERS

// All headers of QGpGuiMath library

#include "ComplexStatisticalPlotProxy.h"
#include "CoordinateConvert.h"
#include "CoordinateFileWidget.h"
#include "CurveBrowser.h"
#include "CurveBrowserCut.h"
#include "CurveBrowserDelegate.h"
#include "CurveBrowserItem.h"
#include "CurveBrowserResample.h"
#include "CurveBrowserSmooth.h"
#include "CurveBrowserSplit.h"
#include "CurveBrowserValidate.h"
#include "CurvePlotProxy.h"
#include "CurvePropertiesWidget.h"
#include "CurveSelector.h"
#include "CurveSelectorItem.h"
#include "FrequencyPlotProxy.h"
#include "GeographicalReference.h"
#include "GuiMathGlobal.h"
#include "ImageLayer.h"
#include "ImageScalingPoint.h"
#include "ImageScalingPointDelegate.h"
#include "ImageScalingPointModel.h"
#include "QGpGuiMathDLLExport.h"
#include "RealStatisticalPlotProxy.h"
#include "SamplingParameterWidget.h"
#include "SmoothingParameterWidget.h"
#include "WindowFunctionParameterWidget.h"
#include "ui_CoordinateConvert.h"
#include "ui_CoordinateFileWidget.h"
#include "ui_CurveBrowser.h"
#include "ui_CurveBrowserCut.h"
#include "ui_CurveBrowserResample.h"
#include "ui_CurveBrowserSmooth.h"
#include "ui_CurveBrowserSplit.h"
#include "ui_CurveBrowserValidate.h"
#include "ui_CurvePropertiesWidget.h"
#include "ui_CurveSelector.h"
#include "ui_GeographicalReference.h"
#include "ui_ImageLayerProperties.h"
#include "ui_ImageScalingPoint.h"
#include "ui_SamplingParameterWidget.h"
#include "ui_SmoothingParameterWidget.h"
#include "ui_WindowFunctionParameterWidget.h"

#ifndef GP_EXPLICIT_LIBRARY_NAMESPACE
using namespace QGpGuiMath;
#endif

#endif // QGPGUIMATH_HEADERS
